@@ -2,7 +2,17 @@
 
 # flake8: noqa
 
-from .git import add, checkout, clone, commit, pull, push, is_git_repo
+from .git import (
+    add,
+    checkout,
+    clone,
+    commit,
+    get_origin_remote,
+    get_top_level,
+    is_git_repo,
+    pull,
+    push,
+)
 from .options import (
     AddOptions,
     CheckoutOptions,
@@ -14,4 +24,4 @@ from .options import (
 from .repository import Repository
 from .workspace import Workspace
 
-__version__ = "0.8.0"
+__version__ = "0.10.1"
